@@ -4,7 +4,7 @@
 # AltaVista.pm
 # by John Heidemann
 # Copyright (C) 1996-1998 by USC/ISI
-# $Id: AltaVista.pm,v 1.29 1998/05/28 04:05:37 johnh Exp $
+# $Id: AltaVista.pm,v 1.30 1998/05/30 18:55:41 johnh Exp $
 #
 # Complete copyright notice follows below.
 #
@@ -220,7 +220,7 @@ sub native_retrieve_some
     print STDERR "WWW::Search::AltaVista::native_retrieve_some: fetching " . $self->{_next_url} . "\n" if ($self->{_debug});
     my($response) = $self->http_request('GET', $self->{_next_url});
     $self->{response} = $response;
-    if (!$response->is_success) {
+        if (!$response->is_success) {
 	return undef;
     };
 
@@ -231,65 +231,83 @@ sub native_retrieve_some
     my($hit) = undef;
     my($raw) = '';
     foreach (split(/\n/, $response->content())) {
-         next if m@^$@; # short circuit for blank lines
-	if ($state == $HEADER && /(<b>)?(no|\d+)<\/b>\s+documents? match/i) {  # post July 1997
-	    my($n) = $2;
+        next if m@^$@; # short circuit for blank lines
+	if (0) {
+	} elsif ($state == $HEADER && /(no|[0-9,]+).*match.*found/i) {  # post 30-May-98
+	    # <font size=-1>No matches were found.</font><P><font size=-1><dl>
+	    # <font size=-1><b>10</b> matches were found. </font><P><font size=-1><P>
+	    # <td valign=top bgcolor=#ffffff><table border=0 width=434 bgcolor=#ffffff height=100% cellpadding=4 cellspacing=0><tr><td valign=top><font face=helvetica size=-1><font face=helvetica size=-1>About <b>14,115,615</b> matches were found. </font><P></font><font face=helvetica size=-1>
+
+	    my($n) = $1;
+	    $n =~ s/,//g;
 	    $n = 0 if ($n =~ /no/i);
 	    $self->approximate_result_count($n);
 	    $state = $HITS;
 	    print STDERR "PARSE(2:HEADER->HITS): $n documents found.\n" if ($self->{_debug} >= 2);
-	} elsif ($state == $HITS && m@(<p><dt>|<dt>)[^"]*<a href=\"([^"]+)"><[a-z]+>(.*)</[a-z]+></a>.*<dd>(.*)(\.)?<br>@i) {  # post March 1998 "
+	} elsif ($state == $HITS && m@(<p><dt>|<dt>|<dt><b>)[^"]*<a[^>]*href=\"([^"]+)"[^>]*>(.*)</a>.*<dd>\s+(\d+\s+\w+\s+\d+)([^"]+)<a@i) {  # post 30-May-98 "
+	    # news is, of course, slightly different
+	    # <dt><b>1. </b><a href="http://ww2.altavista.digital.com/cgi-bin/news?msg@96138@comp%2elang%2eperl%2emisc"><strong>How to Tar &amp; unzip Perl mods on CPAN site on Win32?</strong></a><dd> 8 Jan 98 - <b>comp.lang.perl.misc</b><br><a href="news:34B53D7D.2CED@fast.net">&lt;34B53D7D.2CED@fast.net&gt;</a><br>  <a href="mailto:emorr@fast.net">&quot;Edward Morris, Jr.&quot; &lt;emorr@fast.net&gt;</a><P>
 	    ($hit, $raw) = $self->begin_new_hit($hit, $raw);
 	    $raw .= $_;
 	    $hit->add_url($2);
 	    $hits_found++;
-	    $hit->title($3);
-	    $hit->description(undef_to_emptystring($4) . undef_to_emptystring($5));
-	    print STDERR "PARSE(3:HITS): hit found.\n" if ($self->{_debug} >= 2);
-	} elsif ($state == $HITS && m@^<a href=\"([^"]+)"[^>]*>.*</a>\s*<a href="([^"]+)"[^>]*>.*</a>(.*)</a>@) { # "
-	    # news is slightly different
+	    my($title) = $3;
+	    $title =~ s/<[^>]+>//g;   # strip any accidental formatting in title
+	    $hit->title($title);
+	    $hit->change_date($4);
+	    $hit->description($5);
+	    print STDERR "PARSE(3:HITS): news hit found.\n" if ($self->{_debug} >= 2);
+	} elsif ($state == $HITS && m@(<p><dt>|<dt>|<dt><b>)[^"]*<a[^>]*href=\"([^"]+)"[^>]*>(.*)</a>@i) {  # post 30-May-98
+	    # <dt><b>1. </b><a href="http://www.isi.edu/lsam/tools/autosearch/"><b>index.html directory page</b></a><dd>
 	    ($hit, $raw) = $self->begin_new_hit($hit, $raw);
 	    $raw .= $_;
-	    $hit->add_url($2);   # news:
-	    $hit->add_url($1);   # alta vista url
+	    $hit->add_url($2);
 	    $hits_found++;
-	    $hit->title(undef_to_emptystring($3));
-	    $hit->description(undef_to_emptystring($3));
-	    $hits_found++;
-	    print STDERR "PARSE(4:HITS): news hit found.\n" if ($self->{_debug} >= 2);
-	} elsif ($state == $HITS && /^<cite><a href="([^"]+)">/) { #"
-	    if (defined($hit)) {
-		$raw .= $_;
-	        $hit->add_url($1);
-	        $hits_found++;   # altavista counts URL==hit
-	    };
-	    print STDERR "PARSE(5:HITS): additional hit found.\n" if ($self->{_debug} >= 2);
-	} elsif ($state == $HITS && /^<b>[Tt]ip:/) {
-	    # end, with a list of other pages to go to
-	    ($hit, $raw) = $self->begin_new_hit($hit, $raw);
-	    $state = $TRAILER;
-	    print STDERR "PARSE(6a:HITS->TRAILER).\n" if ($self->{_debug} >= 2);
+	    my($title) = $3;
+	    $title =~ s/<[^>]+>//g;   # strip any accidental formatting in title
+	    $hit->title($title);
+	    $hit->description("");
+	    print STDERR "PARSE(3:HITS): hit found.\n" if ($self->{_debug} >= 2);
+	} elsif ($state == $HITS && m@^([^<]+).*last modified\s+(\S+)\s.*page size\s+(\S+)\s@) { # "
+	    # AutoSearch WEB Searching. What is AutoSearch? AutoSearch performs a web-based search and puts the results set in a web page. It periodically updates this..<br><font size=-2>Last modified 3-Feb-97 - page size 2K - in English [ <a href="http://babelfish.altavista.digital.com/cgi-bin/translate?urltext=http%3a%2f%2fwww%2eisi%2eedu%2flsam%2ftools%2fautosearch%2f&language=en">Translate</a> ]</font><P>
+	    $raw .= $_;
+	    $hit->description($1);
+	    $hit->change_date($2);
+	    my($size) = $3;
+	    $size *= 1024 if ($size =~ s@k$@@i);
+	    $size *= 1024*1024 if ($size =~ s@m$@@i);
+	    $hit->change_size($size);
 	} elsif ($state == $HITS && /<\/dl>/) {
-	    # end, with a list of other pages to go to
+	    # end of hits
 	    ($hit, $raw) = $self->begin_new_hit($hit, $raw);
 	    $state = $TRAILER;
 	    print STDERR "PARSE(6b:HITS->TRAILER).\n" if ($self->{_debug} >= 2);
-	} elsif ($state == $HITS && m@^<\/font><P>.*href="([^"]+)">\s*\[\s*[Nn]ext\s*\]\s*</a>@) { #"
-	    # AdvancedSearch has no Tip
+	} elsif ($state == $HITS) {
+	    # other random stuff in a hit---accumulate it
+	    # <font size=-2>[<b>URL:</b> www.isi.edu/lsam/tools/autosearch/]</font><br>
+
+	    $raw .= $_;
+	} elsif ($state == $TRAILER && /<a[^>]+href="([^"]+)".*\&gt;\&gt;/) { # "
+	    # set up next page
+	    # <a href="/cgi-bin/query?pg=q&text=yes&q=%2bLSAM+%2bISI+%2bwork&stq=10&c9k">[<b>&gt;&gt;</b>]</a> <P>
+
 	    my($relative_url) = $1;
-	    ($hit, $raw) = $self->begin_new_hit($hit, $raw);
+	    # hack:  make sure fmt=d stays on news URLs
+	    $relative_url =~ s/what=news/what=news\&fmt=d/ if ($relative_url !~ /fmt=d/);
 	    $self->{_next_url} = new URI::URL($relative_url, $self->{_base_url});
 	    $state = $POST_NEXT;
-	    print STDERR "PARSE(7:HITS->POST_NEXT).\n" if ($self->{_debug} >= 2);
+	    print STDERR "PARSE(9a:TRAILER->POST_NEXT): found next.\n" if ($self->{_debug} >= 2);
 	} elsif ($state == $TRAILER && /\>\[[Nn]ext\]\</) {
+	    # this section is pre 30-May-98 and should be deleted
 	    # set up next page
 	    my($relative_url) = m@<a\s+href="([^"]+)">\s*\[\s*[Nn]ext\s*\]\s*</a>@; # "
 	    $self->{_next_url} = new URI::URL($relative_url, $self->{_base_url});
 	    $state = $POST_NEXT;
-	    print STDERR "PARSE(9:TRAILER->POST_NEXT): found next.\n" if ($self->{_debug} >= 2);
+	    print STDERR "PARSE(9b:TRAILER->POST_NEXT): found next.\n" if ($self->{_debug} >= 2);
 	} else {
 	    # accumulate raw
 	    $raw .= $_;
+	    print STDERR "PARSE(RAW): $_\n" if ($self->{_debug} >= 3);
 	};
     };
     if ($state != $POST_NEXT) {
